@@ -166,7 +166,7 @@ class ElasticSearchVisitor(Visitor):
     AUTHORS_NAME_VARIATIONS_FIELD = 'authors.name_variations'
     AUTHORS_BAI_FIELD = 'authors.ids.value'
     BAI_REGEX = re.compile(r'^((\w|-|\')+\.)+\d+$', re.UNICODE | re.IGNORECASE)
-    TEXKEY_REGEX = re.compile(r'^\w+:\d{4}\w{2,3}', re.UNICODE)
+    TEXKEY_REGEX = re.compile(r'^[a-zA-Z\.-]+:\d{4}[a-z]{2,3}$', re.UNICODE)
     AUTHORS_NESTED_QUERY_PATH = 'authors'
     FIRST_AUTHOR_NESTED_QUERY_PATH = 'first_author'
     DATE_NESTED_FIELDS = [
@@ -305,6 +305,10 @@ class ElasticSearchVisitor(Visitor):
                     _match_phrase_prefix_query('{}_first_name'.format(keyword), name),
                     _match_query_with_names_initials_analyzer_with_and_operator('{}_first_name'.format(keyword), name)
                 ])
+            if '.' not in parsed_name.first and ',' not in author_name:
+                name_query.append(
+                    _match_query_with_and_operator('author', author_name)
+                )
             should_query.append(
                 wrap_queries_in_bool_clauses_if_more_than_one(
                     name_query, use_must_clause=False)
